//---------------------------------------------------------------------------

#pragma hdrstop

//---------------------------------------------------------------------------
#include "stdlib.h"
#include "stdio.h"
#include "conio.h"
#include "mpt.h"

// The MptDeviceInformation variable is the object which represent the MPT device.
// All MPT related functions require such an instance.
MptDeviceInformation mpt;


#pragma argsused
int main(int argc, char* argv[])
{
    // This function must be called before any other MPT function is used.
    // It only needs be called once. Calling this function more than once
    // is allowed, yet has no effect.
    InitMptLibraries() ;
    fprintf( stdout, "MPT libraries successfully initialized.\n" ) ;

    // The MPT device must be searched for and opened.
    // The OpenFirstMptDevice function tries to do so. It returns the device handle
    // when successful, or INVALID_HANDLE_VALUE when it fails.
    // The handle should not be used by the user. The return value should
    // merely indicate the success of the operation.
    if ( OpenFirstMptDevice(&mpt) == INVALID_HANDLE_VALUE )
    {
        fprintf( stdout, "Cannot locate MPT device. Please make sure it is plugged in.\n" ) ;
        exit( 1 ) ;
    }
    fprintf( stdout, "MPT device opened.\n" ) ;

    // Write to the EUSB. The argumetns are as follows:
    // 1. The MPT argument. This must be the same argument for which the
    //    OpenFirstMptDevice function was called.
    // 2. Port number: 0 or 1
    // 3. Bit number: 0-7 for port 0, 0-3 for port 1.
    //    The port and bit numbers together specify a single line on the EUSB,
    //    to which writing can be made, or from which a reading can be done.
    // 4. Write value: this value represents one bit. The value can be 0,
    //    representing "0", or any other value, representing "1".
    SetDataBit(&mpt, 0,6 , 1);
    SetDataBit(&mpt, 0,7 , 0);
    fprintf( stdout, "Written '1' on 0.6, written '0' on 0.7\n" ) ;

    // Set intensity. The argumetns are as follows:
    // 1. The MPT argument. This must be the same argument for which the
    //    OpenFirstMptDevice function was called.
    // 2. Port number: 0 or 1
    // 3. Bit number: 0-7 for port 0, 0-3 for port 1.
    //    The port and bit numbers together specify a single line on the EUSB,
    //    to which writing can be made, or from which a reading can be done.
    // 4. Intensity, of the rane 0x00 - 0x0f (0-15), when 0 is the lowest
    //    intensity, 15 is the highest.
    SetISink(&mpt, 0,6, 0xf ) ;
    fprintf( stdout, "Intensity set to 0xf on 0.6\n" ) ;

    // Read from the MPT device. The argumetns are as follows:
    // 1. The MPT argument. This must be the same argument for which the
    //    OpenFirstMptDevice function was called.
    // 2. Port number: 0 or 1
    // 3. Bit number: 0-7 for port 0, 0-3 for port 1.
    //    The port and bit numbers together specify a single line on the EUSB,
    //    to which writing can be made, or from which a reading can be done.
    readChar = ReadDataBit(&mpt, 1, 0);
    fprintf( stdout, "Value read from MPT device: %d\n", readChar ) ;

    // Close device: this is required for clean closure of the application.
    // The function releases the device.
    CloseMptDevice(&mpt) ;
    fprintf( stdout, "MPT device successfully closed.\n" ) ;

    fprintf( stdout, "Press ENTER to exit.\n" ) ;
    getch() ;
    return 0;
}
//---------------------------------------------------------------------------
 